@@ -24,8 +24,19 @@ def repository_root():
     try:
         root = subprocess.check_output(['git', 'rev-parse', '--show-toplevel'],
                                        stderr=subprocess.STDOUT).strip()
-        # The str is required to for Python3 to convert the bytes to a str.
-        return str(root)
+        # Convert to unicode first
+        return root.decode('utf-8')
+    except subprocess.CalledProcessError:
+        return None
+
+
+def last_commit():
+    """Returns the SHA1 of the last commit."""
+    try:
+        root = subprocess.check_output(['git', 'rev-parse', 'HEAD'],
+                                       stderr=subprocess.STDOUT).strip()
+        # Convert to unicode first
+        return root.decode('utf-8')
     except subprocess.CalledProcessError:
         return None
 
@@ -38,11 +49,14 @@ def _remove_filename_quotes(filename):
     return filename
 
 
-def modified_files(root, tracked_only=False):
+def modified_files(root, tracked_only=False, commit=None):
     """Returns a list of files that has been modified since the last commit.
 
     Args:
       root: the root of the repository, it has to be an absolute path.
+      tracked_only: exclude untracked files when True.
+      commit: SHA1 of the commit. If None, it will get the modified files in the
+        working copy.
 
     Returns: a dictionary with the modified files as keys, and additional
       information as value. In this case it adds the status returned by
@@ -50,9 +64,14 @@ def modified_files(root, tracked_only=False):
     """
     assert os.path.isabs(root), "Root has to be absolute, got: %s" % root
 
+    if commit:
+        return _modified_files_with_commit(root, commit)
+
+    # Convert to unicode and split
     status_lines = subprocess.check_output(
         ['git', 'status', '--porcelain',
-         '--untracked-files=all']).split(os.linesep)
+         '--untracked-files=all']).decode('utf-8').split(os.linesep)
+
     modes = ['M ', ' M', 'A ', 'AM']
     if not tracked_only:
         modes.append(r'\?\?')
@@ -67,13 +86,34 @@ def modified_files(root, tracked_only=False):
                 for filename, mode in modified_file_status)
 
 
-def modified_lines(filename, extra_data):
+def _modified_files_with_commit(root, commit):
+    # Convert to unicode and split
+    status_lines = subprocess.check_output(
+        ['git', 'diff-tree', '-r', '--root', '--no-commit-id', '--name-status',
+         commit]).decode('utf-8').split(os.linesep)
+
+    modified_file_status = utils.filter_lines(
+        status_lines,
+        r'(?P<mode>A|M)\s(?P<filename>.+)',
+        groups=('filename', 'mode'))
+
+    # We need to add a space to the mode, so to be compatible with the output
+    # generated by modified files.
+    return dict((os.path.join(root, _remove_filename_quotes(filename)),
+                 mode + ' ') for filename, mode in modified_file_status)
+
+
+def modified_lines(filename, extra_data, commit=None):
     """Returns the lines that have been modifed for this file.
 
     Args:
       filename: the file to check.
       extra_data: is the extra_data returned by modified_files. Additionally, a
         value of None means that the file was not modified.
+      commit: the complete sha1 (40 chars) of the commit. Note that specifying
+        this value will only work (100%) when commit == last_commit (with
+        respect to the currently checked out revision), otherwise, we could miss
+        some lines.
 
     Returns: a list of lines that were modified, or None in case all lines are
       new.
@@ -82,11 +122,18 @@ def modified_lines(filename, extra_data):
         return []
     if extra_data not in ('M ', ' M'):
         return None
+
+    if commit is None:
+        commit = '0' * 40
+    commit = commit.encode('utf-8')
+
+    # Split as bytes, as the output may have some non unicode characters.
     blame_lines = subprocess.check_output(
-        ['git', 'blame', '--porcelain', filename]).split(os.linesep)
+        ['git', 'blame', '--porcelain', filename]).split(
+            os.linesep.encode('utf-8'))
     modified_line_numbers = utils.filter_lines(
         blame_lines,
-        r'0000000000000000000000000000000000000000 (?P<line>\d+) (\d+)',
+        commit + br' (?P<line>\d+) (\d+)',
         groups=('line',))
 
-    return map(int, modified_line_numbers)
+    return list(map(int, modified_line_numbers))
