@@ -31,7 +31,7 @@ class GitLintTest(unittest.TestCase):
     def setUpClass(cls):
         cls._stderr = sys.stderr
         sys.stderr = sys.stdout
-        cls.git_lint_config = gitlint.get_config()
+        cls.git_lint_config = gitlint.get_config(None)
 
     @classmethod
     def tearDownClass(cls):
@@ -50,6 +50,11 @@ class GitLintTest(unittest.TestCase):
         self.git_repository_root = self.git_repository_root_patch.start()
         self.addCleanup(self.git_repository_root_patch.stop)
 
+        self.hg_repository_root_patch = mock.patch(
+            'gitlint.hg.repository_root', return_value=None)
+        self.hg_repository_root = self.hg_repository_root_patch.start()
+        self.addCleanup(self.hg_repository_root_patch.stop)
+
         self.git_modified_files_patch = mock.patch(
             'gitlint.git.modified_files', return_value={self.filename: ' M'})
         self.git_modified_files = self.git_modified_files_patch.start()
@@ -60,6 +65,11 @@ class GitLintTest(unittest.TestCase):
         self.git_modified_lines = self.git_modified_lines_patch.start()
         self.addCleanup(self.git_modified_lines_patch.stop)
 
+        self.git_last_commit_patch = mock.patch(
+            'gitlint.git.last_commit', return_value="abcd" * 10)
+        self.git_last_commit = self.git_last_commit_patch.start()
+        self.addCleanup(self.git_last_commit_patch.stop)
+
         self.lint_patch = mock.patch(
             'gitlint.linters.lint')
         self.lint = self.lint_patch.start()
@@ -72,15 +82,15 @@ class GitLintTest(unittest.TestCase):
         self.git_modified_lines.reset_mock()
         self.lint.reset_mock()
 
-    def assert_mocked_calls(self, tracked_only=False):
+    def assert_mocked_calls(self, tracked_only=False, commit=None):
         """Checks if the mocks were called as expected.
 
         This method exists to avoid duplication.
         """
         self.git_modified_files.assert_called_once_with(
-            self.root, tracked_only=tracked_only, commit=None)
+            self.root, tracked_only=tracked_only, commit=commit)
         self.git_modified_lines.assert_called_once_with(
-            self.filename, ' M', commit=None)
+            self.filename, ' M', commit=commit)
         self.lint.assert_called_once_with(
             self.filename, [3, 14], self.git_lint_config)
 
@@ -136,6 +146,21 @@ class GitLintTest(unittest.TestCase):
         self.assertIn('OK', self.stdout.getvalue())
         self.assert_mocked_calls()
 
+    def test_main_file_changed_and_still_valid_with_commit(self):
+        lint_response = {
+            self.filename: {
+                'comments': []
+            }
+        }
+        self.lint.return_value = lint_response
+
+        self.assertEqual(
+            0,
+            gitlint.main(
+                ['git-lint', '--last-commit'], stdout=self.stdout, stderr=None))
+        self.assertIn('OK', self.stdout.getvalue())
+        self.assert_mocked_calls(commit='abcd' * 10)
+
     def test_main_file_changed_and_still_valid_tracked_only(self):
         lint_response = {
             self.filename: {
@@ -440,20 +465,20 @@ class GitLintTest(unittest.TestCase):
             mock.patch('gitlint.open',
                        mock.mock_open(read_data=config),
                        create=True) as mock_open:
-            parsed_config = gitlint.get_config()
+            parsed_config = gitlint.get_config(self.root)
             mock_open.assert_called_once_with(git_config)
             self.assertEqual(['.py'], list(parsed_config.keys()))
             self.assertEqual(1, len(parsed_config['.py']))
 
     def test_get_config_from_default(self):
         with mock.patch('os.path.exists', return_value=False):
-            parsed_config = gitlint.get_config()
+            parsed_config = gitlint.get_config(self.root)
             self.assertEquals(self.git_lint_config, parsed_config)
 
     def test_get_config_not_in_a_repo(self):
         # When not in a repo should return the default config.
         self.git_repository_root.return_value = None
-        parsed_config = gitlint.get_config()
+        parsed_config = gitlint.get_config(None)
         self.assertEquals(self.git_lint_config, parsed_config)
 
     def test_get_config_empty(self):
@@ -462,7 +487,7 @@ class GitLintTest(unittest.TestCase):
             mock.patch('gitlint.open',
                        mock.mock_open(read_data=''),
                        create=True) as mock_open:
-            parsed_config = gitlint.get_config()
+            parsed_config = gitlint.get_config(self.root)
             self.assertEqual({}, parsed_config)
 
     def test_format_comment(self):
@@ -506,3 +531,17 @@ class GitLintTest(unittest.TestCase):
                             'severity': 'Error',
                             'message_id': 'not-used',
                          }))
+
+    def test_get_vcs_git(self):
+        self.git_repository_root.return_value = self.root
+        self.assertEquals((gitlint.git, self.root), gitlint.get_vcs_root())
+
+    def test_get_vcs_hg(self):
+        self.git_repository_root.return_value = None
+        self.hg_repository_root.return_value = self.root
+        self.assertEquals((gitlint.hg, self.root), gitlint.get_vcs_root())
+
+    def test_get_vcs_none(self):
+        self.git_repository_root.return_value = None
+        self.hg_repository_root.return_value = None
+        self.assertEquals((None, None), gitlint.get_vcs_root())
